@@ -41,44 +41,40 @@ class ArgumentParser:
         self.name = ""
         self.mail = ""
 
-    def owner(self, name: str, mail: str, version: str):
+    def owner(self, name: str, version: str):
         self.name = name
-        self.mail = mail
         self.version_number = version
 
     def from_dict(self, data: dict):
-        for key, value in data.items():
+
+        meta = data["metadata"]
+        self.description = meta["description"]
+        self.epilog = meta["epilog"]
+        self.name = meta["owner"]
+        self.version_number = meta["version"]
+
+        args = data["arguments"]
+        for key, value in args.items():
             short = value["short"]
             type = getattr(builtins, value["type"]) if "type" in value.keys() else str
             required = value["required"] if "required" in value.keys() else True
             description = value["description"] if "description" in value.keys() else ""
             choices = value["choices"] if "choices" in value.keys() else []
+            multiple = value["multiple"] if "multiple" in value.keys() else False
+            self.add(key, short, type, required, description, choices, multiple)
 
-            self.add(key, short, type, required, description, choices)
+    def from_file(self, path: str):
+        ext = path.split(".")[-1]
 
-    def from_json(self, path: str):
-        """Use the content of the json file at path to fill list of arguments to parse.
-
-        Parameters
-        ----------
-        path: string
-            Path (absolute or relative) to the json file.
-        """
-        with open(path, "r") as f:
-            data = json.load(f)
-
-        self.from_dict(data)
-
-    def from_yaml(self, path: str):
-        """Use the content of the yaml file at path to fill list of arguments to parse.
-
-        Parameters
-        ----------
-        path: string
-            Path (absolute or relative) to the json file.
-        """
-        with open(path, "r") as f:
-            data = yaml.load(f, Loader=yaml.FullLoader)
+        if ext == "json":
+            with open(path, "r") as f:
+                data = json.load(f)
+        elif ext == "yaml":
+            with open(path, "r") as f:
+                data = yaml.load(f, Loader=yaml.FullLoader)
+        else:
+            print("Not a valid file extension. Option file must be a jsonor yaml file.")
+            exit()
 
         self.from_dict(data)
 
@@ -199,9 +195,12 @@ class ArgumentParser:
     def version(self):
         """Displays the current version of the program."""
         program_name = sys.argv[0].split("\\")[-1]
-        print(
-            f"'{program_name}' version {self.version_number} by {self.name} <{self.mail}>"
-        )
+
+        if self.name != "":
+            print(f"'{program_name}' version {self.version_number} by {self.name}")
+        else:
+            print(f"'{program_name}' version {self.version_number}")
+            print("Version number can be changed with parser.owner() method")
 
     def help(self):
         """Displays help for the argument to pass on the command-line."""
@@ -249,44 +248,57 @@ class ArgumentParser:
         value: dictionnary
             dictionnary of all values related to key.
         """
-        print(f"{value['short']}: {key:{length_str+10}s} {value['type']}")
-        print(f"\t{value['description']}")
-        if value["choices"]:
-            print(f"\tPossible values are {value['choices']}.")
 
-    def to_json(self, filename: str):
+        print(f"{value['short']}: {key:{length_str+10}s} {value['type']}", end="")
+
+        if value["multiple"]:
+            print(f" (list of values accepted)")
+        else:
+            print("")
+        if value["description"]:
+            print(f"\t{value['description']}")
+        if value["choices"]:
+            print(f"\tPossible values are {value['choices']}")
+
+    def to_file(self, path: str):
         """Export the arguments dictionnary to a json file.
 
         Parameters
         ----------
-        filename: string
-            name of the json file to send dictionnary values to.
+        path: string
+            name of the json or yaml file to send dictionnary values to.
         """
+
+        # arguments
         args = copy.deepcopy(self.arguments)
 
         for key in args.keys():
             args[key]["type"] = args[key]["type"].__name__
             args[key]["short"] = args[key]["short"][1]
 
-        with open(filename, "w") as f:
-            json.dump(args, f)
+        # meta
+        meta = {
+            "description": self.description,
+            "epilog": self.epilog,
+            "owner": self.name,
+            "version": self.version_number,
+        }
 
-    def to_yaml(self, filename: str):
-        """Export the arguments dictionnary to a yaml file.
+        output = {"metadata": meta, "arguments": args}
 
-        Parameters
-        ----------
-        filename: string
-            name of the yaml file to send dictionnary values to.
-        """
-        args = copy.deepcopy(self.arguments)
+        ext = path.split(".")[-1]
 
-        for key in args.keys():
-            args[key]["type"] = args[key]["type"].__name__
-            args[key]["short"] = args[key]["short"][1]
-
-        with open(filename, "w") as f:
-            yaml.dump(args, f)
+        if ext == "json":
+            with open(path, "w") as f:
+                json.dump(output, f)
+        elif ext == "yaml":
+            with open(path, "w") as f:
+                yaml.dump(output, f)
+        else:
+            print(
+                "Not a valid file extension. Option file must be a json or yaml file."
+            )
+            exit()
 
     def __getitem__(self, key: str) -> Any:
         """Returns the value (with the right type) associated with a given key. If the key correspond to an optional argument that has not been given, the method returns None.
@@ -323,20 +335,20 @@ class ArgumentParser:
                         if self.in_choices(key, v, value_type):
                             return_list.append(value_type(v))
                         else:
-                            print(f"Provided {key} not in possible values.")
+                            print(f"Provided {key} not allowed.")
                             exit()
                     return return_list
                 else:
                     if self.in_choices(key, result, value_type):
                         return [value_type(result)]
                     else:
-                        print(f"Provided {key} not in possible values.")
+                        print(f"Provided {key} not allowed.")
                         exit()
             else:
                 if self.in_choices(key, result, value_type):
                     return value_type(result)
                 else:
-                    print(f"Provided {key} not in possible values.")
+                    print(f"Provided {key} not allowed.")
                     exit()
 
         except ValueError as e:
@@ -348,5 +360,4 @@ class ArgumentParser:
     def in_choices(self, key: str, value: Any, value_type: type) -> bool:
         choices = [value_type(c) for c in self.arguments[key]["choices"]]
 
-     
         return not (choices and value_type(value) not in choices)
